@@ -1,5 +1,4 @@
-#include <cassert>
-#include <cmath>
+// #include <cassert>
 #include "Sscma.h"
 #include "Subsets.h"
 #include "Vsmabo.h"
@@ -15,13 +14,13 @@ void savfrst()
 {
 	subset* fset;
 
-	assert(flst >= 0 && flst < p+1);
+//	assert(flst >= 0 && flst < p+1);
 	fset = &SW->subsetat(flst+1);
 	for (vind i=lp;i<p-1;i++) {
 		actv[i-lp] = fset->getithvar(i) + 1;
-		assert(actv[i-lp] > 0 && actv[i-lp] <= p);
+//		assert(actv[i-lp] > 0 && actv[i-lp] <= p);
 	}
-	assert(lastvar > 0 && lastvar <= p);  
+//	assert(lastvar > 0 && lastvar <= p);  
 	actv[p-lp-1] = lastvar;
 	sbset* st = csbset(fp,actv,fset->getdata().criterion(),fset->getdata().indice());
 	bsts[0]->insert(st);
@@ -35,17 +34,17 @@ void savfull(void)
 {
 	subset* wlst; 
 
-	assert(flst >= 0 && flst <= p);
+//	assert(flst >= 0 && flst <= p);
 	wlst = &IW->subsetat(flst+1);
 	{ for (vind i=0;i<fp;i++) {
 		actv[i] = wlst->getithvar(i)+1;
-		assert(actv[i] > 0 && actv[i] <= p);
+//		assert(actv[i] > 0 && actv[i] <= p);
 	} }
 	{ for (vind i=fp+lp;i<p-1;i++) {
 		actv[i-lp] = wlst->getithvar(i)+1;
-		assert(actv[i-lp] > 0 && actv[i-lp] <= p);
+//		assert(actv[i-lp] > 0 && actv[i-lp] <= p);
 	} }
-	assert(lastvar > 0 && lastvar <= p);  
+//	assert(lastvar > 0 && lastvar <= p);  
 	actv[p-lp-1] = lastvar;
 	sbset*  st = csbset(p-lp,actv,wlst->getdata().criterion(),wlst->getdata().indice());
 	bsts[p-lp-mindim]->insert(st);
