@@ -1,11 +1,8 @@
-#include <cassert>
 #include <cmath>
 #include "Sscma.h"
 #include "Vsmabo.h"
 #include "RMcrt.h"
 
-using namespace std;
-
 namespace extendedleaps {
 
 #ifdef COUNTING  
