@@ -1,20 +1,19 @@
+#include <R.h>
 #include <iostream>
-#include <cstdlib>
-#include "Sscma.h" 
 
 using namespace std; 
 
 namespace extendedleaps {
 
-void msg(const string& s)
-{
-	cout << s;
-}
-
 void errmsg(const string& s)
 {
-	cerr << s;
-	exit(1);	
+	Rf_error("%s",s.c_str());
+}
+
+
+void msg(const string& s)
+{
+	Rprintf("%s",s.c_str());
 }
 
 }
