@@ -25,13 +25,17 @@ class vsqfdata :  public sqfdata {
 		real*   getvc(void)	{ return &vc[0]; }
 		void  setvc(real* x,vind nparcels);  
 		void  setvc(real* x)   { setvc(x,r);  }  
-		virtual real updatesum(direction dir,mindices& mmind,vind var,vind dim,partialvsqfdata *pdt) const;
-		virtual void pivot(direction dir,mindices& mmind,vind vp,vind t,vind dim,partialvsqfdata* pdt,vsqfdata* fdt,bool last);
+		virtual real updatesum(direction dir,mindices& mmind,vind var,vind dim,partialvsqfdata *pdt,bool& reliable,const double tol) const;
+		virtual void pivot(direction dir,mindices& mmind,vind vp,vind t,vind dim,partialvsqfdata* pdt,vsqfdata* fdt,bool last,
+					bool& reliable,const double tol);
 	private:
-		real updatesum(direction dir,vind varind,vind dim,partialvsqfdata* newdata) const;   
-		void pivot(direction dir,lagindex<d>& prtmmit,vind vp,vind t,vind dim,partialvsqfdata* newpdata,vsqfdata* newfdata,bool last);
-		void pivot(direction dir,lagindex<i>& prtmmit,vind vp,vind t,vind dim,partialvsqfdata* newpdata,vsqfdata* newfdata,bool last);
+		real updatesum(direction dir,vind varind,vind dim,partialvsqfdata* newdata,bool& reliable,const double tol) const;   
+		void pivot(direction dir,lagindex<d>& prtmmit,vind vp,vind t,vind dim,partialvsqfdata* newpdata,vsqfdata* newfdata,bool last,
+			bool& reliable,const double tol);
+		void pivot(direction dir,lagindex<i>& prtmmit,vind vp,vind t,vind dim,partialvsqfdata* newpdata,vsqfdata* newfdata
+			,bool last,bool& reliable,const double tol);
 		vector<real>	vc;
+		real **rpl;  // Vector of pointers to reals whose accuracy will be monitered  
 };
 
 }
